import React from 'react';
import { Download } from 'lucide-react';
import { 
  Accordion, 
  AccordionContent, 
  AccordionItem, 
  AccordionTrigger 
} from "@/components/ui/accordion";
import { Button } from '@/components/ui/button';

interface Activity {
  label: string;
  description?: string;
}

interface Accommodation {
  type: string;
  name: string;
  link?: string;
  alternatives?: string;
}

export interface ItineraryDay {
  day: string;
  title: string;
  description: string[];
  activities?: Activity[];
  accommodations?: Accommodation[];
  images?: string[];
}

interface ItineraryAccordionProps {
  itineraryDays: ItineraryDay[];
  onDownloadPdf: () => void;
}

const ItineraryAccordion = ({ itineraryDays, onDownloadPdf }: ItineraryAccordionProps) => {
  return (
    <div className="bg-white rounded-lg shadow-md p-6">
      <div className="flex justify-between items-center mb-4">
        <h2 className="text-2xl font-display font-bold text-gray-900">Tour Itinerary</h2>
        <Button 
          onClick={onDownloadPdf} 
          variant="outline" 
          className="border-primary text-primary hover:bg-primary/10"
        >
          <Download size={18} className="mr-2" />
          Download PDF
        </Button>
      </div>

      <Accordion type="single" collapsible className="w-full  border-gray-200">
        {itineraryDays.map((day, index) => (
          <AccordionItem key={index} value={`day-${index}`} className="py-1"  isLast={index === itineraryDays.length - 1}>
            <AccordionTrigger className="hover:no-underline py-5 group">
              <div className="flex flex-col sm:flex-row sm:items-center gap-2 text-left">
                <span className="bg-primary text-white px-3 py-1 rounded-full text-sm font-medium inline-block min-w-[80px] text-center">
                  {day.day}
                </span>
                <h3 className="text-xl font-semibold group-hover:text-primary transition-colors">
                  {day.title}
                </h3>
              </div>
            </AccordionTrigger>
            
            <AccordionContent className="pt-2 pb-4">
              <div className="space-y-4 text-gray-700">
                {day.description.map((paragraph, idx) => (
                  <p key={idx} className="leading-relaxed">{paragraph}</p>
                ))}
                
                {day.activities && day.activities.length > 0 && (
                  <div className="mt-4">
                    <h4 className="text-base font-semibold text-gray-800 mb-2">Activities:</h4>
                    <ul className="list-disc pl-5 space-y-1">
                      {day.activities.map((activity, idx) => (
                        <li key={idx} className="text-gray-700">
                          <span className="font-medium">{activity.label}</span>
                          {activity.description && <span>: {activity.description}</span>}
                        </li>
                      ))}
                    </ul>
                  </div>
                )}
                
                {day.accommodations && day.accommodations.length > 0 && (
                  <div className="mt-4">
                    <h4 className="text-base font-semibold text-gray-800 mb-2">
                      Overnight Stay:
                    </h4>
                    {day.accommodations.map((accommodation, idx) => (
                      <p key={idx} className="text-gray-700 italic">
                        {accommodation.name}
                        {accommodation.alternatives && (
                          <span> / {accommodation.alternatives}</span>
                        )}
                      </p>
                    ))}
                  </div>
                )}
                
                {day.images && day.images.length > 0 && (
                  <div className="mt-4 grid grid-cols-2 md:grid-cols-4 gap-3">
                    {day.images.map((image, idx) => (
                      <div key={idx} className="rounded-lg overflow-hidden h-24 border border-gray-200">
                        <img 
                          src={image} 
                          alt={`Day ${day.day} - Image ${idx + 1}`} 
                          className="w-full h-full object-cover"
                        />
                      </div>
                    ))}
                  </div>
                )}
              </div>
            </AccordionContent>
          </AccordionItem>
        ))}
      </Accordion>
    </div>
  );
};

export default ItineraryAccordion;